==> wiki_passage_retriever-0.1.4-py3-none-any.whl: wiki_passage_retriever/utils.py <==
import requests
from bs4 import BeautifulSoup
from urllib.request import urlopen
import re
from typing import List, Callable


__all__ = ['retrieve_wiki_page']


def remove_citation(paragraph: str) -> str:
    """Remove all citations (numbers in side square brackets) in paragraph"""
    return re.sub(r'\[\d+\]', '', paragraph)


def remove_new_line(paragraph: str) -> str:
    return paragraph.replace("\n", "")


def compose_fns(functions: List[Callable]) -> Callable:
    def ret(input):
        for fn in functions:
            input = fn(input)

        return input

    return ret


def retrieve_page_content(url: str) -> List[str]:
    html = urlopen(url)
    soup = BeautifulSoup(html, 'html.parser')

    preprocess_fn = compose_fns([remove_citation, remove_new_line])
    paragraphs = list(map(lambda p: preprocess_fn(p.getText()), soup.find_all('p')))

    return paragraphs


def retrieve_wiki_page(query: str) -> List[str]:
    """Searches wikpedia for a query, gets the first result, then extracts all the paragraphs."""
    session = requests.Session()
    api_url = "https://en.wikipedia.org/w/api.php"

    params = {
        "action": "query",
        "format": "json",
        "list": "search",
        "srsearch": query
    }

    response = session.get(url=api_url, params=params)
    data = response.json()

    # only get the first result
    page_id = data['query']['search'][0]['pageid']
    return retrieve_page_content("https://en.wikipedia.org/?curid={}".format(page_id))

==> wiki_passage_retriever-0.1.5a2-py3-none-any.whl: wiki_passage_retriever/utils.py <==
import requests
from bs4 import BeautifulSoup
from urllib.request import urlopen
import re
from typing import List, Callable
import nltk
from nltk.tokenize import sent_tokenize
import itertools


__all__ = ['retrieve_wiki_page']


MIN_SENTENCE_LENGTH = 4  # filter sentences with less than 4 characters (likely to be noise)


def remove_citation(paragraph: str) -> str:
    """Remove all citations (numbers in side square brackets) in paragraph"""
    return re.sub(r'\[\d+\]', '', paragraph)


def remove_new_line(paragraph: str) -> str:
    return paragraph.replace("\n", "")


def compose_fns(functions: List[Callable]) -> Callable:
    def ret(input):
        for fn in functions:
            input = fn(input)

        return input

    return ret


def retrieve_page_content(url: str) -> List[str]:
    html = urlopen(url)
    soup = BeautifulSoup(html, 'html.parser')

    nltk.download('punkt')  # make sure that the tokenizer is downloaded

    paragraphs = list(map(lambda p: p.getText(), soup.find_all('p')))
    sentences = itertools.chain.from_iterable(map(sent_tokenize, paragraphs))
    preprocess_fn = compose_fns([remove_citation, remove_new_line])

    # preprocess sentences, stripping starting and trailing spaces, and then filter out too short sentences
    return list(filter(lambda sent: len(sent) > MIN_SENTENCE_LENGTH, map(lambda sent: preprocess_fn(sent).strip(), sentences)))


def retrieve_wiki_page(query: str) -> List[str]:
    """Searches wikpedia for a query, gets the first result, then extracts all the paragraphs."""
    session = requests.Session()
    api_url = "https://en.wikipedia.org/w/api.php"

    params = {
        "action": "query",
        "format": "json",
        "list": "search",
        "srsearch": query
    }

    response = session.get(url=api_url, params=params)
    data = response.json()

    # only get the first result
    page_id = data['query']['search'][0]['pageid']
    return retrieve_page_content("https://en.wikipedia.org/?curid={}".format(page_id))
